	********************************************************************************************************
	  ****************************************************************************************************
	  **																								**
	  **									Kapitel 2: Grundlagen der Regressionsanalyse				**
	  **																								**
	  **	Bitte zitieren Sie bei Verwendung dieses Do-Files											**
	  **	Wenzelburger, Georg/Jckle, Sebastian/Knig, Pascal: Weiterfhrende statistische Methoden 	**
	  **	fr Politikwissenschaftler. Eine anwendungsbezogene Einfhrung mit Stata, Oldenbourg 2014	**
	  **																								**
	  ** 	Verwendete Datenstz: "Grundlagen_der_Regressionsanalyse1.dta"								**
	  **   					      "Grundlagen_der_Regressionsanalyse2.dta"								**
	  **																								**
	  ****************************************************************************************************
	********************************************************************************************************


	
*********************************								 //Hierfr Datensatz "Grundlagen_der_Regressionsanalyse1.dta" verwenden	
*** Kovarianz und Korrelation ***	
*********************************

**Streudiagramme 
twoway scatter euimage eubenefit, ///
xtitle(EU Nutzenbewertung) ytitle(EU-Image) mlabel(country)      //Streudiagramm zur Darstellung des Zusammenhangs EU-Nutzenbewertung X allgemeines EU-Image
twoway scatter euimage euinsttrust, ///
xtitle(EU Nutzenbewertung) ytitle(EU-Image) mlabel(country)      //Streudiagramm zur Darstellung des Zusammenhangs EU-Institutionenvertrauen X allgemeines EU-Image
twoway scatter euimage  eucitizen, ///
xtitle(EU Nutzenbewertung) ytitle(EU-Image) mlabel(country)      //Streudiagramm zur Darstellung des Zusammenhangs EU-Identifikation X allgemeines EU-Image
twoway scatter euimage  eucitizen, ///
xtitle(EU Nutzenbewertung) ytitle(EU-Image) mlabel(country)      //Streudiagramm zur Darstellung des Zusammenhangs Bewertung EU-Krisenmanagement X allgemeines EU-Image

*Abbildung 2.1: Streudiagramm ber euimage und eubenefit
sum euimage eubenefit 										     //Ausgabe der Mittelwerte der verwendeten Variablen
graph twoway (scatter euimage eubenefit, ///
mlabel(country)), xtitle(EU Nutzenbewertung) ///
ytitle(EU-Image) yline(.55544, lpattern(dash)) ///
xline(.6304, lpattern(dash)) 								     //Zur Veranschaulichung Mittelwerte im Streudiagramm eingezeichnet

**Berechnung von Kovarianz und Korrelation
correl  euimage eubenefit, covariance						     //Kovarianz fr den Zusammenhang EU-Nutzenbewertung X allgemeines EU-Image
correl  euimage eubenefit 								         //Korrelation nach Pearson ber den usammenhang EU-Nutzenbewertung X allgemeines EU-Image

*Output 2.1: Korrelationsmatrix
correl  euimage eubenefit  euinsttrust  eucitizen  eucapable     //Korrelationsmatrix fr alle fnf Variablen (die Label-Variable ausgenommen) im Datensatz 

*Abbildung 2.2: Scatterplotmatrix 
graph matrix euimage eubenefit euinsttrust eucitizen eucapable   //gibt die Streudiagramme (siehe oben) fr die Zusammenhnge jeder Variablen mit jeweils allen anderen Variablen wieder



*************************************
***  Bivariate lineare Regression ***
*************************************

*Abbildung 2.3: Bivariate Regression von euimage auf eucapable
sum euimage eucapable 											 //Ausgabe der Mittelwerte der verwendeten Variablen
graph twoway (lfit euimage eucapable) ///
(scatter euimage eucapable, mlabel(country)), ///
xtitle(Bewertung Krisenmanagement EU) ytitle(EU-euimage) ///
yline(.55544, lpattern(dash)) xline(.4937222, lpattern(dash))    //Streudiagramm mit Regressionsgerade samt Mittelwerten der Variablen; der Befehl lfit erzeugt hierbei die Gerade

*Output 2.2
regress euimage eucapable 										 //Liefert den Regressionsoutput zu der vorangehenden Grafik

*Vorhersage von Werten der abhngigen Variablen aus Output 2.2
display .4943563* .6  + .3103216 		   						 //Vorhergesagter Wert euimage, eucapable denn Wert 0,6 annimmt (~ 0,607)
lincom eucapable* .6  + _cons 			    					 //Alternative Berechnung mit Befehl fr Linearkombinationen von Schtzern (nicht im Buchkapitel enthalten):
																 //_cons steht fr die Konstante im zuvor berechneten Modell
*Output 2.3: Bivariate Regression mit stand. Koeffizienten
regress euimage eucapable, beta									 //Ausgabe der standardisierten Effektschtzer



***********************************								 //Datensatz "Grundlagen_der_Regressionsanalyse2.dta" verwenden
*** Multiple lineare Regression ***								 //Es handelt sich hierbei um eine gekrzte und aufbereitete Version des Eurobaromer 75.3(ZA5481, GESIS Datenarchiv) 
***********************************

*Zur Generierung der verwendeten Variablen siehe die Befehle weiter unten 
									
*Output 2.4: Multiple Regression
regress eueuimage eubenefit euinsttrust eucitizen eucapable ///
age gender educ leftright occup1 occup2 occup3 occup5 ///
occup6 occup7 occup8 if COUNTRY==9 | COUNTRY==10 [w=W4]			 //Regressionsmodell mit if-Bedingung fr die Auswahl des Vereinigten Knigreichs und mit entsprechender Gewichtung

*Output 2.5: Multiple Regression mit stand. Koeffizienten
regress eueuimage eubenefit euinsttrust eucitizen eucapable ///
age gender educ leftright occup1 occup2 occup3 occup5 ///
occup6 occup7 occup8 if COUNTRY==9 | COUNTRY==10 [w=W4], beta	 //Erneute Berechnung mit standardisierten Koeffizienten (Betas)



**********************************************************************************************************	
* HINWEIS:  Fr die Regressiondiagnostik wird nachfolgend zunchst wieder der erste Datensatz verwendet. * 
* 	        Die Multikollinearitt wird jedoch anhand der zuvor berechneten Regression veranschaulicht.	 *
**********************************************************************************************************	



***************************
** Regressionsdiagnostik **
***************************

**Linearitt													 //Datensatz "Grundlagen_der_Regressionsanalyse1.dta" verwenden	
*Berechnen der Residuen fr die Regression 
*von euimage auf eubenefit
regress euimage eubenefit
predict r, resid											     //Durch die Regression vorhergesagte Residuen berechnen lassen

*Abbildung 2.6: Streudiagramm der Residuen fr eubenefit
twoway (scatter r eubenefit), yline(0)							 //Darstellung der ber der Variablen eubenefit abgetragenen Residuen; horizontale Linie (yline) zur Veranschaulichung
rvpplot eubenefit, yline(0)										 //Alternativer Befehl fr diese Darstellung


**Homoskedatizitt
*Berechnen des Regressionsmodells
regress euimage eubenefit

*Output 2.6: Test auf Heteroskedastizitt 
hettest														     //Test auf Heteroskedastizitt durchfhren; Zu beachten ist die Signifikanz fr den resultierenden Chi-Wert

*Erneute Berechnung des Modells mit robusten Standardfehlern
regress euimage eubenefit, r								     //Bei robusten Standardfehlern (Option ", r") ndern sich die Konfidenzintervalle der Schtzer


**Multikollinearitt											 //Hierfr Datensatz "Grundlagen_der_Regressionsanalyse2.dta" verwenden	
*Berechnen des Regressionsmodells
regress eueuimage eubenefit euinsttrust eucitizen eucapable ///
age gender educ leftright occup1 occup2 occup3 occup5 ///
occup6 occup7 occup8 if COUNTRY==9 | COUNTRY==10 [w=W4]

*Output 2.7: Multikollinearitt und Varianzinflationsfaktor
vif															     //Gibt die Werte fr die Varianzinflation zu der zuvor berechneten Regression an


**Normalverteilung der Residuen									 //Datensatz "Grundlagen_der_Regressionsanalyse1.dta" verwenden	
*Berechnen des Regressionsmodells und der Residuen
regress euimage eubenefit
predict r, resid

*Output 2.8: Test auf Normalverteilung der Residuen
swilk r															 //Shapiro-Wilk-Test auf Normalverteilung; zu beachten ist die Signifikanz (Prob>z)
sktest r														 //Alternativer test mittels Schiefe und Wlbung der Verteilung

*Abbildung 2.7: Geglttete Kurve der Residuenverteilung
kdensity r, normal											 	 //Grafik zum visuellen Abgleich der Residuenverteilung mit der Normalverteilung


**Einflussreiche Flle
*Berechnen des Regressionsmodells 
regress euimage eubenefit

*Berechnen der studentisierten Residuen 
predict rstud, rstudent
gen absrstud = abs(rstud)										 //Da das Vorzeichen der Abweichung fr den Abweicherstatus nicht von Interesse ist, werden die Absolutwerte berechnet 

*Output 2.8: Studentisierte Residuen
sort absrstud
list absrstud rstud country in  -5/L						     //Liste zur Prfung mglicher Ausreier (extreme Werte in Y-Richtung) mit den fnf grten abs. Abweichungen

*Einfluss auf Gesamtmodell prfen
predict DFFITS, dfits											 //Berechnung der DFFITS-Werte
gen absDFFITS = abs(DFFITS)										 //Da der absolute Einfluss von Interesse ist, werden entsprechend die Absolutwerte berechnet 

*Output 2.9: DFFITS-Werte
list DFFITS country if absDFFITS>2*sqrt((1+1)/27) 				 //Auflistung der Flle, die nach der hierbei verwendeten Daumenregel als einflussreich gelten 

predict cooksd, cooksd											 //Alternativ kann auch Cook's D als Ma fr den Einfluss der Flle auf das gesamte Modell herangezogen werden
list cooksd country if cooksd>4/27								 //Auflistung der Flle mit vorhergesagten Cook's D ber dem Schwellenwert 4/N



*****************************************************************************
***  Rekodieren der Variablen aus dem verwendeten Eurobarometer-Datensatz ***
*****************************************************************************

drop  eueuimageraw-leftright									//Entfernt die erstellten Variablen aus dem aufbereiteten Datensatz

*Erstellen der abhngigen Variablen allgemeine Wahrnehmung (Image) der EU
recode QA14 (1=5) (2=4) (3=3) (4=2) (5=1)(6=.), gen(eueuimageraw)
gen eueuimage = (eueuimageraw-1)/4
sum eueuimage, d

*Erstellen der Variablen wahrgenommener Nutzen durch EU
recode QA11C (1=1) (2=0) (3=.), gen(eubenefit)
tab eubenefit

*Erstellen der Variablen Vertrauen in die Institutionen der EU
recode QA17_1 QA17_2 QA17_3 QA17_4 (1=1)(2=0)(3=.)
gen euinsttrust =  (QA17_1+ QA17_2 +QA17_3 +QA17_4)/4 			//Normieren der Variablen auf den Bereich 0 bis 1
sum euinsttrust, d

*Erstellen der Variablen gefhlte Identitt als EU-Brger
recode QD4_1(1=4) (2=3) (3=2) (4=1) (5=.), gen(eucitizenraw)
gen eucitizen = (eucitizenraw-1)/3								//Lineartransformation, um die Variablen auf den Bereich 0 bis 1 zu normieren
sum eucitizen, d

*Erstellen der Variablen Wahrnehmung der EU-Handlungskompetenz in der Finanz- und Wirtschaftskrise 
recode QC11_1 (1=4) (2=3) (3=2) (4=1) (5=.), gen(eucapableraw)
gen eucapable = (eucapableraw-1)/3								//Lineartransformation, um die Variablen auf den Bereich 0 bis 1 zu normieren

*Erstellen der soziodemographischen Variablen
gen age= VD11 													//Alter
recode D10 (2=0), gen(gender) 									//recode Geschlecht

sum VD8, d
recode VD8 (98 99 =.), gen(educ) 								//Bildungsgrad (= Alter bei Abschluss als Proxy)
	
tabulate C14, gen(occup)										//Beschftigung; occup4 = Arbeiter als Referenzkategorie verwendet
label variable occup1 "self-employed"
label variable occup2 "managers"
label variable occup3 "other white collars"
label variable occup4 "manual workers"
label variable occup5 "house person"
label variable occup6 "unemployed"
label variable occup7 "retired"
label variable occup8 "students"
						
recode D1 (11 12=.),gen(leftright)  							//Links-Rechts-Selbsteinstufung

