	********************************************************************************************************
	  ****************************************************************************************************
	  **																								**
	  **									Kapitel 3: Interaktionen									**
	  **																								**
	  **	Bitte zitieren Sie bei Verwendung dieses Do-Files											**
	  **	Wenzelburger, Georg/Jckle, Sebastian/Knig, Pascal: Weiterfhrende statistische Methoden 	**
	  **	fr Politikwissenschaftler. Eine anwendungsbezogene Einfhrung mit Stata, Oldenbourg 2014	**
	  **																								**
	  ** 	Verwendeter Datensatz: "Interaktionen.dta" 													**
	  **	Quellen: Daten zur Hhe der Lohnersatzraten nach Lyle Scruggs (2004), Kabinettssitzanteile	**
	  **	und Vetopunkte-Index nach Allan und Scruggs (2004).											**
	  **																								**
	  ****************************************************************************************************
	********************************************************************************************************


***BEISPIEL 1: Interaktion mit dichotomer Z-Variable***

**Generierung einer dichotomen Z-Variable aus der Veto-Variable
sum veto90, det // luft von 1,65 bis 9, Median bei 4,5
recode veto90 (1/9 = 1), gen(vetodich) // Generierung der dichotomen Variable = 1
recode veto90 (1/4.5 = 0)
tab veto90 vetodich //Kontrolle, ob Rekodierung funktioniert hat

**Regression mit dichotomer Veto-Variable zur Illustration
gen vetdichsd = vetodich*proz_sd9099

reg delsick9099 proz_sd vetodich sick_rr90 // ohne Interaktion
reg delsick9099 proz_sd vetodich vetdichsd sick_rr90 // mit Interaktion
rvfplot //Ein Blick auf die Residuen 
hettest //Heteroskedastizitt?

**Interpretation mittels Grafiken
*Ausgangsgleichung
reg delsick9099 proz_sd vetodich vetdichsd sick_rr90

*Vorhergesagte Werte, wenn alle anderen Variablen am Mittelwert, Variation Z-Variable und ProzSD
gen yhat0 = _b[_cons] + _b[proz_sd9099]*proz_sd9099 + _b[vetodich]*0 + _b[vetdichsd]*proz_sd9099*0 + _b[sick_rr90]*67.1 
gen yhat1 = _b[_cons] + _b[proz_sd9099]*proz_sd9099 + _b[vetodich]*1 + _b[vetdichsd]*proz_sd9099*1 + _b[sick_rr90]*67.1 
scatter yhat* proz_sd9099

graph twoway line yhat0 yhat1 proz_sd9099, sort

drop yhat*

*Vorgesagte Werte und Standardfehler bzw. Konfidenzintervalle mit lincom
reg delsick9099 proz_sd vetodich vetdichsd sick_rr90
lincom _cons + proz_sd9099*0 + vetodich*0 + vetdichsd*0*0 + sick_rr*67.1
lincom _cons + proz_sd9099*77.37 + vetodich*0 + vetdichsd*77.37*0 + sick_rr*67.1
lincom _cons + proz_sd9099*0 + vetodich*1 + vetdichsd*0*1 + sick_rr*67.1
lincom _cons + proz_sd9099*77.37 + vetodich*1 + vetdichsd*77.37*1 + sick_rr*67.1

*Grafik mit entsprechenden Linien fr die Konfidenzintervalle
lincom _cons + proz_sd9099*0 + vetodich*0 + vetdichsd*0*0 + sick_rr*67.1
lincom _cons + proz_sd9099*10 + vetodich*0 + vetdichsd*10*0 + sick_rr*67.1
lincom _cons + proz_sd9099*20 + vetodich*0 + vetdichsd*20*0 + sick_rr*67.1
lincom _cons + proz_sd9099*30 + vetodich*0 + vetdichsd*30*0 + sick_rr*67.1
lincom _cons + proz_sd9099*40 + vetodich*0 + vetdichsd*40*0 + sick_rr*67.1
lincom _cons + proz_sd9099*50 + vetodich*0 + vetdichsd*50*0 + sick_rr*67.1
lincom _cons + proz_sd9099*60 + vetodich*0 + vetdichsd*60*0 + sick_rr*67.1
lincom _cons + proz_sd9099*70 + vetodich*0 + vetdichsd*70*0 + sick_rr*67.1
lincom _cons + proz_sd9099*80 + vetodich*0 + vetdichsd*80*0 + sick_rr*67.1


lincom _cons + proz_sd9099*0 + vetodich*1 + vetdichsd*0*1 + sick_rr*67.1
lincom _cons + proz_sd9099*10 + vetodich*1 + vetdichsd*10*1 + sick_rr*67.1
lincom _cons + proz_sd9099*20 + vetodich*1 + vetdichsd*20*1 + sick_rr*67.1
lincom _cons + proz_sd9099*30 + vetodich*1 + vetdichsd*30*1 + sick_rr*67.1
lincom _cons + proz_sd9099*40 + vetodich*1 + vetdichsd*40*1 + sick_rr*67.1
lincom _cons + proz_sd9099*50 + vetodich*1 + vetdichsd*50*1 + sick_rr*67.1
lincom _cons + proz_sd9099*60 + vetodich*1 + vetdichsd*60*1 + sick_rr*67.1
lincom _cons + proz_sd9099*70 + vetodich*1 + vetdichsd*70*1 + sick_rr*67.1
lincom _cons + proz_sd9099*80 + vetodich*1 + vetdichsd*80*1 + sick_rr*67.1


***BEISPIEL 2: Interaktion mit quasi-metrischer Variable***

**Regression mit quasi-metrischer Variable
gen vetsd = veto90*proz_sd9099

reg delsick9099 proz_sd veto90 sick_rr90 // ohne Interaktion
reg delsick9099 proz_sd veto90 vetsd sick_rr90 // mit Interaktion
rvfplot //Ein Blick auf die Residuen 
hettest //Heteroskedastizitt?


**Vorhergesagte Werte und Grafik der Effekte (ohne Konf Interv)
*Vorhergesagte Werte, wenn alle anderen Variablen am Mittelwert, Variation Z-Variable von 0 bis 9 und ProzSD
gen yhat0 = _b[_cons] + _b[proz_sd9099]*proz_sd9099 + _b[veto90]*0 + _b[vetsd]*proz_sd9099*0 + _b[sick_rr90]*67.1 
gen yhat1 = _b[_cons] + _b[proz_sd9099]*proz_sd9099 + _b[veto90]*1 + _b[vetsd]*proz_sd9099*1 + _b[sick_rr90]*67.1 
gen yhat2 = _b[_cons] + _b[proz_sd9099]*proz_sd9099 + _b[veto90]*2 + _b[vetsd]*proz_sd9099*2 + _b[sick_rr90]*67.1 
gen yhat3 = _b[_cons] + _b[proz_sd9099]*proz_sd9099 + _b[veto90]*3 + _b[vetsd]*proz_sd9099*3 + _b[sick_rr90]*67.1 
gen yhat4 = _b[_cons] + _b[proz_sd9099]*proz_sd9099 + _b[veto90]*4 + _b[vetsd]*proz_sd9099*4 + _b[sick_rr90]*67.1 
gen yhat5 = _b[_cons] + _b[proz_sd9099]*proz_sd9099 + _b[veto90]*5 + _b[vetsd]*proz_sd9099*5 + _b[sick_rr90]*67.1 
gen yhat6 = _b[_cons] + _b[proz_sd9099]*proz_sd9099 + _b[veto90]*6 + _b[vetsd]*proz_sd9099*6 + _b[sick_rr90]*67.1 
gen yhat7 = _b[_cons] + _b[proz_sd9099]*proz_sd9099 + _b[veto90]*7 + _b[vetsd]*proz_sd9099*7 + _b[sick_rr90]*67.1 
gen yhat8 = _b[_cons] + _b[proz_sd9099]*proz_sd9099 + _b[veto90]*8 + _b[vetsd]*proz_sd9099*8 + _b[sick_rr90]*67.1 
gen yhat9 = _b[_cons] + _b[proz_sd9099]*proz_sd9099 + _b[veto90]*9 + _b[vetsd]*proz_sd9099*9 + _b[sick_rr90]*67.1 

graph twoway line yhat* proz_sd9099, sort

drop yhat*

**Marginal Effects Plot

version 8.0 
#delimit ;

reg delsick9099 proz_sd veto90 vetsd sick_rr90;

*     ****************************************************************  *;
*       Generate the values of Z for which you want to calculate the    *;
*       marginal effect (and standard errors) of X on Y.                *;
*     ****************************************************************  *;

generate MV=((_n-1)/1);
replace  MV=. if _n>10;

*     ****************************************************************  *;
*       Grab elements of the coefficient and variance-covariance matrix *;
*       that are required to calculate the marginal effect and standard *;
*       errors.                                                         *;
*     ****************************************************************  *;

reg delsick9099 proz_sd veto90 vetsd sick_rr90;

matrix b=e(b);
matrix V=e(V);
 
scalar b1=b[1,1];
scalar b2=b[1,2];
scalar b3=b[1,3];


scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];

scalar covb1b3=V[1,3]; 
scalar covb2b3=V[2,3];

scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;



*     ****************************************************************  *
*       Calculate the marginal effect of X on Y for all MV values of    *
*       the modifying variable Z.                                       *
*     ****************************************************************  *

#delimit ;
gen conb=b1+b3*MV if _n<11;


*     ****************************************************************  *
*       Calculate the standard errors for the marginal effect of X on Y *
*       for all MV values of the modifying variable Z.                  *
*     ****************************************************************  *

#delimit ;
gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<11;


*     ****************************************************************  *
*       Generate upper and lower bounds of the confidence interval.     *
*       Specify the significance of the confidence interval.            *
*     ****************************************************************  *
#delimit ;

gen a=1.96*conse;
 
gen upper=conb+a;
 
gen lower=conb-a;


#delimit ;

*     ****************************************************************  *;
*       Graph the marginal effect of X on Y across the desired range of *;
*       the modifying variable Z.  Show the confidence interval.        *;
*     ****************************************************************  *;

graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   ,   
             xlabel(0 1 2 3 4 5 6 7 8 9 , labsize(2.5)) 
             ylabel(1 -0.5 0 0.5 1, labsize(2.5))
             yscale(noline)
             xscale(noline)
             legend(col(1) order(1 2) label(1 "Marg. Effekt sd Parteien") 
                                      label(2 "95% Konfidenzintervall") 
                                      label(3 " "))
             yline(0, lcolor(black))   
             title("Marginaler Effekt Parteien sd durch VPS", size(4))
             subtitle(" " "Abh. Variable: Vernderung 9099 RR Sickpay" " ", size(3))
             xtitle( "VPS", size(3)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             ytitle("Marginaler Effekt sd Parteien", size(3))
             scheme(s2mono) graphregion(fcolor(white));

drop MV conb conse a upper lower;



