	********************************************************************************************************
	  ****************************************************************************************************
	  **																								**
	  **									Kapitel 4: Logistische Regressionsanalyse					**
	  **																								**
	  **	Bitte zitieren Sie bei Verwendung dieses Do-Files											**
	  **	Wenzelburger, Georg/Jckle, Sebastian/Knig, Pascal: Weiterfhrende statistische Methoden 	**
	  **	fr Politikwissenschaftler. Eine anwendungsbezogene Einfhrung mit Stata, Oldenbourg 2014	**
	  **																								**
	  ** 	Verwendeter Datensatz: "Logistische_Regressionsanalyse.dta"									**
	  **				   Quelle: International Social Survey Programme, Role of Government IV (2006), **
	  **						   gekrzte und aufbereitete Version									**
	  ****************************************************************************************************
	********************************************************************************************************


***DESKRIPTIVE STATISTIK UND BIVARIATE ANALYSE***

**Deskriptive Statistik
sum VOTE_LE polint attend topbot educyrs age, det //hier bereinigter Datensatz; wenn tatschlich - Missing bei educyrs 95 und 96 (ber recode)
codebook VOTE_LE polint attend topbot educyrs age, det //hier bereinigter Datensatz; wenn tatschlich - Missing bei educyrs 95 und 96 (ber recode)

**Bivariate Zusammenhnge
*Kreuztabellen: Nominal bzw. ordinale Variablen
tab polint VOTE_LE, chi2 cchi2 V
tab attend VOTE_LE, chi2 cchi2 V //dieser Output wird im Buch berichtet
tab topbot VOTE_LE, chi2 cchi2 V

*Mann-Whitney-Test
ranksum polint, by(VOTE_LE)
ranksum attend, by(VOTE_LE) //dieser Output wird im Buch berichtet
ranksum topbot, by(VOTE_LE)

*T-Test fr metrische Variablen
histogram age // sieht auf den ersten Blick ganz okay aus
mvtest normality age, all // Normalverteilung gegeben
sdtest age, by(VOTE_LE) // Varianzen in den Gruppen signifikant unterschiedlich
robvar age, by(VOTE_LE) // Varianzen in den Gruppen signifikant unterschiedlich
ttest age, by(VOTE_LE) uneq

***LOGISTISCHE REGRESSIONSANALYSE***
**Dummies generieren
tab attend, gen(attdum)
tab union, gen(uniondum)

**Modellschtzung
logit VOTE_LE polint attdum1-attdum5 uniondum1 uniondum2 topbot educyrs age  //dieser Output wird im Kapitel berichtet

**Fitmae
fitstat //verschiedene Mae
lstat //Klassifikationsmatrix

*Beispiel zum Modellvergleich (Output nicht in Buchkapitel) mit "Fitstat, diff"
logit VOTE_LE polint attdum1-attdum5 uniondum1 uniondum2 topbot age  // Modell ohne Bildungsvariable
fitstat, save // Speichert Fitstatistiken nach erster Schtzung ab
logit VOTE_LE polint attdum1-attdum5 uniondum1 uniondum2 topbot educyrs age // Modell mit Bildungsvariable
fitstat, diff force // Vergleich der Fitmae; Option "force", weil N von Modell 2 um 4 Einheiten von Modell 1 abweicht (sollte bei greren Abweichungen nicht genutzt werden)

**Interpretation des Einflusses der unabhngigen Variablen

*Odds-Ratios
logit VOTE_LE polint attdum1-attdum5 uniondum1 uniondum2 topbot educyrs age, or   //dieser Output wird im Kapitel berichtet
logistic VOTE_LE polint attdum1-attdum5 uniondum1 uniondum2 topbot educyrs age // Alternative fr Odds Ratios - nicht im Buch aber identischer Output

listcoef // Andere Darstellung der Odds-Ratios (nicht im Buchkapitel)
listcoef, reverse //Berechnet die Kehrwerte der ORs - wichtig fr Interpretation der Strke der negativen Effekte
listcoef, percent //Berechnet die Odds-Ratios als Prozentvernderungen
listcoef, percent reverse //OR als Prozentvernderungen, reverse


*Vorhergesagte Wahrscheinlichkeiten
logit VOTE_LE polint attdum1-attdum5 uniondum1 uniondum2 topbot educyrs age
predict prob, pr // Vorhergesagte Wahrscheinlichkeiten der Funktion
histogram prob, freq //Histogramm
dotplot prob // andere Darstellungsform von Verteilungen
drop prob // Lschen der generierten Variable

prvalue, x(educyrs=7) rest(mean) // Vorhergesagte Werte fr erste Kategorie der Bildungsvariable - folgende Zeilen, weitere Kategorien
prvalue, x(educyrs=8) rest(mean) 
prvalue, x(educyrs=9) rest(mean) 
prvalue, x(educyrs=10) rest(mean) 
prvalue, x(educyrs=11) rest(mean) 
prvalue, x(educyrs=12) rest(mean) 
prvalue, x(educyrs=13) rest(mean) 
prvalue, x(educyrs=14) rest(mean) 
prvalue, x(educyrs=15) rest(mean) 
prvalue, x(educyrs=16) rest(mean) 
prvalue, x(educyrs=17) rest(mean) 
prvalue, x(educyrs=18) rest(mean)

prchange, help // Vernderung der vorhergesagten Werte fr bestimmte Vernderungen der X-Variablen; help-Option gibt Erklrungen zur Tabelle an

prtab educyrs, rest(mean) // Vorhergesagte Werte mit prtab, nur Bildungsgrad (schnere Darstellung als ber die einzelnen prvalue Befehle) (nicht in Buchkapitel)
prtab educyrs polint, rest(mean) nolabel // Vorhergesagte Werte mit prtab fr zwei Variablen ohne Labels (aus Darstellungsgrnden)

prgen educyrs, from(7) to(18) generate (int1) x(polint=1) rest(mean) n(12) //Vorhergesagte Werte fr unterschiedlichen Bildungsgrad und polint=1, wobei eine neue Variable generiert wird 
label var int1p1 "very interested"
prgen educyrs, from(7) to(18) generate (int2) x(polint=2) rest(mean) n(12) //Vorhergesagte Werte fr unterschiedlichen Bildungsgrad und polint=2, wobei eine neue Variable generiert wird
label var int2p1 "fairly interested"
prgen educyrs, from(7) to(18) generate (int3) x(polint=3) rest(mean) n(12) //Vorhergesagte Werte fr unterschiedlichen Bildungsgrad und polint=3, wobei eine neue Variable generiert wird
label var int3p1 "somewhat interested"
prgen educyrs, from(7) to(18) generate (int4) x(polint=4) rest(mean) n(12) //Vorhergesagte Werte fr unterschiedlichen Bildungsgrad und polint=4, wobei eine neue Variable generiert wird
label var int4p1 "not very interested"
prgen educyrs, from(7) to(18) generate (int5) x(polint=5) rest(mean) n(12) //Vorhergesagte Werte fr unterschiedlichen Bildungsgrad und polint=5, wobei eine neue Variable generiert wird
label var int5p1 "not at all interested"

// Nchste Zeile: Liniengrafik mit fnf Linien (fr die unterschiedlichen Niveaus des pol. Interesses und Bildungsgrad auf x-Achse
graph twoway connected int1p1 int2p1 int3p1 int4p1 int5p1 int5x, ytitle("Wahrsch Wahlbeteiligung")  xtitle("Bildungsgrad") xlabel(7(1)18)


**Interpretation der Signifikanz der unabhngigen Variablen
logit VOTE_LE polint attdum1-attdum5 uniondum1 uniondum2 topbot educyrs age //Interpetation der Signifikanzen aus dem Output

test polint //Wald-Test direkt
test topbot age //Wald-Test fr zwei Variablen, nicht in Buchkapitel

logit VOTE_LE attdum1-attdum5 uniondum1 uniondum2 topbot educyrs age if polint !=. //Schtzung 1
estimates store mod1 //Speichern
logit VOTE_LE polint attdum1-attdum5 uniondum1 uniondum2 topbot educyrs age //Schtzung 2
estimates store mod2 //Speichern
lrtest mod1 mod2 //LRTest

logit VOTE_LE polint attdum1-attdum5 uniondum1 uniondum2 topbot educyrs age //Schtzung volles Modell
lrdrop1 //Kurzbefehl fr mehrere LR-Tests. ACHTUNG: Den Befehl muss man vor Benutzung ber "findit lrdrop" herunterladen!


**Regressionsdiagnostik
*Spezifikation
logit VOTE_LE polint attdum1-attdum5 uniondum1 uniondum2 topbot educyrs age //Schtzung
linktest

lowess VOTE_LE topbot, xlabel (1(1)10) ylabel(0(.2)1) bwidth(.5) //Berichtet im Buchkapitel
lowess VOTE_LE topbot, bwidth(.2) // Schtzungen mit unteschiedlichen Bandbreiten
lowess VOTE_LE topbot, bwidth(.4)
lowess VOTE_LE topbot, bwidth(.6)
lowess VOTE_LE topbot, bwidth(.8)

*Einflussreiche Flle
logit VOTE_LE polint attdum1-attdum5 uniondum1 uniondum2 topbot educyrs age //Schtzung
predict cooksd, db //Cooks Distanzen
scatter cooksd V2 //Scatter der Cooks Distanzen
predict persres2, dx2
predict leverage, hat

*Multikollinearitt
correl VOTE_LE polint attdum1-attdum5 uniondum1 uniondum2 topbot educyrs age //Kein Problem!
reg VOTE_LE polint attdum1-attdum5 uniondum1 uniondum2 topbot educyrs age //OLS-Regression zur Berechnung des VIF
vif //Kein Problem!




