	********************************************************************************************************
	  ****************************************************************************************************
	  **																								**
	  **									Kapitel 5: Mehrebenenanalyse								**
	  **																								**
	  **	Bitte zitieren Sie bei Verwendung dieses Do-Files											**
	  **	Wenzelburger, Georg/Jckle, Sebastian/Knig, Pascal: Weiterfhrende statistische Methoden 	**
	  **	fr Politikwissenschaftler. Eine anwendungsbezogene Einfhrung mit Stata, Oldenbourg 2014	**
	  **																								**
	  ** 	Verwendeter Datensatz: "Mehrebenenanalyse.dta" 												**
	  **				   Quelle: Special Eurobarometer 297: Attitudes towards radioactive waste, 		**
	  **						   gekrzte und aufbereitete Version									**
	  ****************************************************************************************************
	********************************************************************************************************


/*	Mittelwerte der Gruppen und Standardabweichungen garanked abtragen --> liefert ersten Eindruck davon, inwiefern relevante Gruppenunterschiede vorliegen --> nicht in Kapitel beschrieben */
by country, sort: egen mean_atomeinstellung = mean(atomeinstellung) 
by country, sort: egen sd_atomeinstellung = sd(atomeinstellung)
sort mean_atomeinstellung
egen pickone_atomeinstellung = tag(countrycode)
generate u0rank_atomeinstellung = sum(pickone_atomeinstellung)
label define atomeinstellunglabel 1 "Sweden" 2 "Denmark" 3 "Netherlands" 4 "Hungary" 5 "Bulgaria" 6 " Slovakia" 7 "Lithuania" 8 "Czech Republic" 9 "Finland" 10 "Estonia" 11 "Poland" 12 "Slovenia" 13 "France" 14 "Belgium" 15 "Germany" 16 "Great Britain" 17 "Romania" 18 "Ireland" 19 "Italy" 20 "Luxembourg" 21 "Latvia" 22 "Greece" 23 "Spain" 24 "Cyprus" 25 "Portugal" 26 "Austria" 27 "Malta", replace
label values  u0rank_atomeinstellung atomeinstellunglabel
serrbar mean_atomeinstellung sd_atomeinstellung u0rank_atomeinstellung if pickone_atomeinstellung==1, scale(1.96) 


/* 	Output 5.1: Zwei-Ebenen Nullmodell  */
xtmixed atomeinstellung || countrycode: if filter ==1,  variance mle
estat ic
display "deviance = " -2*e(ll)

/* 	Residuen des berechneten Zwei-Ebenen Nullmodells speichern */
estimates store nullmodel

/* 	Hndische Berechnung des IKK / VPC:
	Berechnung des VPC Variance Partitition Coefficient der fr einfache Mehrebenenmodelle gleich dem 
	Intraclass Correlation Coefficient ICC ist
	The variance partition coefficient (VPC) measures the proportion of total variance that is due to 
	differences between groups:

	var(_cons)/(var(_cons) + var(_residual)) = .0886027 / (.0886027 + .4692475) = VPC = ICC = 0.1588
	Interpretation: If the VPC is 0.1588, for example, we would say that 15.88% of the variation is 
	between groups and 84.12% within. The correlation between randomly chosen pairs of individuals belonging 
	to the same group is 0.1588.

	Gibt es einen signifikanten level-2 effekt, d.h. eien signifikanten in between groups effekt? --> 
	Likelihhod Ratio Chi-Quadrat Test zwischen Zwei-Ebenen Nullmodell und Single-Level-Nullmodell --> 
	Hierzu mssen die zuflligen Level-Zwei Effekte ("|| contrycode") aus dem Modell herausgenommen werden */


/* Single-Level-Nullmodell */
xtmixed atomeinstellung if filter ==1, mle variance 


/*	Mit dem LIKELIHOOD RATIO TEST kann man entscheiden, ob es einen signifikanten Einfluss   
	der level 2 Einheiten gibt                                                              
	hierzu rechnet man den log-likelihood Wert des null multi level models - den log-like   
	lihood Wert des null single level models                                                
	und das ganze dann mit 2 malgenommen also 2x(LL_nullmultilevel - LL_nullsinglelevel)    
	bei df = 1, weil man nur einen parameter ndert ("||countrycode") --> 					
	alles was ber 3,84 ist, ist signifikant  */                               				


/* 	EINFACHER 
	Stata berechnet den Likelihhod ratio Wert direkt bei der Berechnung des Zwei-Ebenen Nullmodells  = chibar2(01) = 3923.64  
	--> signifikanter Einfluss der Level-Zwei-Einheiten vorhanden --> Mehrebenenmodellierung sinnvoll */

/*
 Graphische Darstellung der Gruppenresiduen
*/

/* Rckgriff auf das Zwei-Ebenen Nullmodell */
xtmixed atomeinstellung || countrycode: if filter ==1,  variance reml

/* Output 5.2 */
/* Residuen fr die einzelnen Level-2 Einheiten */
predict u0, reffects

/* Standardfehler fr diese Residuen */
predict u0se, reses

/* Sortieren entsprechend der Hhe des Residuums: */
sort u0

/* 	Die Residuen und ihre Standardfehler sind fr jeden einzelnen Fall im Datensatz berechnet worden. 
	Um jedoch zusammenfassende Statistiken und Grafiken generieren zu knnen generiert man eine dummy-variable "pickone"
	die jeweils einen einzelnen Fall pro Level-Zwei-Einheit herausgreift. */

egen pickone = tag(countrycode)



/* 	Auflisten der Level-Zwei-Residuen + Standardfehler */

list country u0 u0se if pickone==1 

/* 	INTERPRETATION 
	Land 1, sterreich, hat ein Residuum von .6140339 und liegt auf Rang 26. Aus dem Parameter des Zwei-Ebenen Nullmodells 2.138607 
	und dem Residuum fr sterreich lsst sich ein mean score fr sterreich von 2.138607 + .6140339 = 2,7526409 berechnen.
	Analog fr Ungarn (Rang 5): 2.138607 - .2587321 = 1,8798749 */

	/*	Um die Level-Zwei-Effkte zu ranken verwendet man den "generate" command zusammen mit der "sum"-Funktion
	um eine neue Variable "u0rank" zu generieren, die der kumulativen Summe von "pickone" entspricht. */

/* Abbildung 5.4*/ 
generate u0rank = sum(pickone)
serrbar u0 u0se u0rank if pickone==1, scale(1.96) yline(0) 
/* 	Darstellung der Residuen fr die Level-Zwei-Einheiten in einem Caterpillar-Plot (+ 95% Konfidenzintervalle)
	Die Reihenfolge der Variablen im command ist wichtig: 
	Die erste Variable beinhaltet den Punktschtzer, die zweite die dazugehrigen Standardfehler und die dritte den Rangplatz des Punktschtzers.
	Mit der "scale(1.96)"-Option erhlt man die 95% Konfidenzintervallgrenzen und "yline(0)" generiert eine Refernzlinie, die die durchschnittliche
	Level-Zwei-Einheit in den Daten widerspiegelt. */

drop _est_nullmodel u0 u0se pickone u0rank /*nicht mehr bentigte Variablen lschen*/

/*	Modellierung von Level-Eins-Effekten  */
/*	Random-Intercept-Modell  */

/*  Zentrieren von Alter und Wissen  */
sum alter
gen z_alter = alter - r(mean)

sum wissen
gen z_wissen = wissen - r(mean)

/* Output 5.3*/
/* 	mit Restrictes Maximum Likelihood (REML) = Standard in Stata */
xtmixed atomeinstellung  z_alter geschlecht  z_wissen || countrycode: if filter==1,  variance  
 
/* 	mit klassischer Maximum Likelihood  */
xtmixed atomeinstellung  z_alter geschlecht  z_wissen || countrycode: if filter==1,  mle variance   


/*	Random-Slope-Modell  */

/*	Random Slopes fr Alter testen  */
/*	zunchst Random Intercept zum Vergleich  */
xtmixed atomeinstellung  z_alter geschlecht  z_wissen || countrycode: if filter==1,  variance 

/*Output 5.4*/
/* dann Random Slope nur fr Alter */
xtmixed atomeinstellung  z_alter geschlecht  z_wissen || countrycode: z_alter if filter==1, covariance(unstructured)  variance 
/* Vergleich der LR-Werte Testgre = (2* Differenz der LR-Werte) hier: 2* (-109698.72+109604.74) = 187,96 --> 
bei df = 2 (eins fr alter random slope, eins fr Kovarianz zwischen Slopes und Intercepts) braucht man laut theoretischer Chi-Quadrat Tabelle 
mindestens 5,99 --> Random Slopes sinnvoll */

/*mit MLE */
xtmixed atomeinstellung  z_alter geschlecht  z_wissen || countrycode: z_alter if filter==1, covariance(unstructured)  variance mle 

/*	Random Slopes fr Geschlecht testen  */
/*	zunchst Random Intercept zum Vergleich  */
xtmixed atomeinstellung  z_alter geschlecht  z_wissen || countrycode: if filter==1,  variance 
/* dann Random Slope nur fr Geschlecht */
xtmixed atomeinstellung  z_alter geschlecht  z_wissen || countrycode: geschlecht if filter==1, covariance(unstructured)  variance 
/* Vergleich der LR-Werte Testgre = (2* Differenz der LR-Werte) hier: 2* (-109698.72+109681.65) = 34,14 --> 
bei df = 2 (eins fr Geschlecht random slope, eins fr Kovarianz zwischen Slopes und Intercepts) braucht man laut theoretischer Chi-Quadrat Tabelle
bei 95% Vertrauenswahrscheinlichkeit mindestens 5,99 --> Random Slopes sinnvoll */

/*	Random Slopes fr Wissen testen  */
/*	zunchst Random Intercept zum Vergleich  */
xtmixed atomeinstellung  z_alter geschlecht  z_wissen || countrycode: if filter==1,  variance 
/* dann Random Slope nur fr Wissen */
xtmixed atomeinstellung  z_alter geschlecht  z_wissen || countrycode: z_wissen if filter==1, covariance(unstructured)  variance 
/* Vergleich der LR-Werte Testgre = (2* Differenz der LR-Werte) hier: 2* (-109698.72+109625.74) = 145,96 --> 
bei df = 2 (eins fr Wissen random slope, eins fr Kovarianz zwischen Slopes und Intercepts) braucht man laut theoretischer Chi-Quadrat Tabelle
bei 95% Vertrauenswahrscheinlichkeit mindestens 5,99 --> Random Slopes sinnvoll */

/*Abbildung 5.8*/
*age random slope plot
xtmixed atomeinstellung  alter  || countrycode: alter  if filter==1, covariance(unstructured) variance 
predict predscore, fitted
sort countrycode alter
egen pickone = tag(countrycode alter)
twoway connected predscore alter if pickone==1, connect(ascending)
drop predscore pickone /* Lschen der nicht mehr bentigten Variablen*/
 
*age random slope plot (Alter zentriert)
xtmixed atomeinstellung  z_alter  || countrycode: z_alter  if filter==1, covariance(unstructured) variance 
predict predscore, fitted
sort countrycode z_alter
egen pickone = tag(countrycode z_alter)
twoway connected predscore z_alter if pickone==1, connect(ascending) 
drop predscore pickone /* Lschen der nicht mehr bentigten Variablen*/
 
* Korrelationsplot Slope vs. Intercept
predict u1 u0, reffects
*Je einen Wert pro Land rauspicken und im scatterplot abtragen:
egen pickone = tag(countrycode)
scatter u1 u0 if pickone==1, yline(0) xline(0) ytitle("slope of z_alter (u1j)") xtitle("Intercept (u0j)")
drop u1 u0 pickone /*Lschen der nicht mehr bentigten Variablen*/

/*Output 5.5*/
/* Random-Slope Alter Modell + Level-2-Variable grne */
xtmixed atomeinstellung  z_alter geschlecht  z_wissen grne || countrycode: z_alter if filter==1, covariance(unstructured)  variance mle

/*Output 5.6*/
/* Cross-Level-Interaktion zwischen Alter und Grne */
/* Interaktionseffekt generieren */
gen z_alter_grne = z_alter * grne
/* Random-Slope Alter Modell + Level-2-Variable grne + Cross Level-Interaktion zentriert*/
xtmixed atomeinstellung  z_alter geschlecht  z_wissen grne z_alter_grne || countrycode: z_alter if filter==1, covariance(unstructured)  variance 
estat ic
/* Random-Slope Alter Modell + Level-2-Variable grne + Cross Level-Interaktion nicht-zentriert*/
gen alter_grne = alter* grne
xtmixed atomeinstellung alter geschlecht  wissen grne alter_grne || countrycode: alter if filter==1, covariance(unstructured)  variance

/*Output 5.7*/
/* AIC und BIC */
/* Vergleich von random Intercept und random Slope fr Alter */
/* Random Intercept */
/* 	mit Restrictes Maximum Likelihood (REML) = Standard in Stata */
xtmixed atomeinstellung  z_alter geschlecht  z_wissen || countrycode: if filter==1,  variance  
estat ic
/* random Slope */
xtmixed atomeinstellung  z_alter geschlecht  z_wissen || countrycode: z_alter if filter==1, covariance(unstructured)  variance 
estat ic
