	********************************************************************************************************
	  ****************************************************************************************************
	  **																								**
	  **									Kapitel 6: Gepoolte Zeitreihenanalyse						**
	  **																								**
	  **	Bitte zitieren Sie bei Verwendung dieses Do-Files											**
	  **	Wenzelburger, Georg/Jckle, Sebastian/Knig, Pascal: Weiterfhrende statistische Methoden 	**
	  **	fr Politikwissenschaftler. Eine anwendungsbezogene Einfhrung mit Stata, Oldenbourg 2014	**
	  **																								**
	  ** 	Verwendeter Datensatz: "Gepoolte_Zeitreihenanalyse.dta" 									**
	  **				  Quellen:	Lohnersatzrate nach Scruggs et al. 2013, + eigene Zusammenstellung	**
	  ****************************************************************************************************
	********************************************************************************************************

**3.1 DATENSATZSTRUKTUR und VARIANZAUFTEILUNG**
tsset ccode year

xtsum UEmean regpos_lire jahn1 fed //Varianzzerlegung
xtline UEmean, i(countryshort) t(year) //Liniengrafik; Option i und t fr Darstellung der Lnder

**3.2 ZEITLICHE DYNAMIK**

*3.2.1 Nicht Stationaritt*
gen ldv = l.UEmean //Lagged dependent variable erzeugen
xtreg UEmean ldv, fe //Regression LDV auf Abh. Variable

levinlin UEmean, lag(1) //Levin-Lin-Chu-Test: ACHTUNG - dieser Test muss vorher aus dem Internet heruntergeladen werden ber "findit levinlin", dann Installation des Pakets
ipshin UEmean, lag(1) //Im-Pesaran-Shin-Test: ACHTUNG - dieser Test muss vorher aus dem Internet heruntergeladen werden ber "findit ipshin", dann Installation des Pakets
levinlin UEmean, lag(1) trend //LLC mit Trend
ipshin UEmean, lag(1) trend //IPS mit Trend

xtunitroot llc UEmean, lag(1) // ab Stata 11 ber xtunitroot ein schnerer Output

*3.2.2 Serielle Autokorrelation*
*Entdeckung und Tests
reg UEmean regpos_lire jahn1 fed deficit_t1 unemp_t1 openc ud //Pooled OLS
rvfplot, mlabel(countryshort) //Residuen vs. fitted values, Lnderlabels
rvfplot, mlabel(year) //Residuen vs. fitted values, Jahreslabels

reg UEmean regpos_lire jahn1 fed deficit_t1 unemp_t1 openc ud //Pooled OLS
predict res, res //Vorhersage der Residuen
gen lagres = l.res //Lag der Residuen
xtreg res lagres, fe //FE-Autoregression der Residuen auf sich selbst
drop res lagres //Lschen der generierten Variablen

xtserial UEmean regpos_lire jahn1 fed deficit_t1 unemp_t1 openc ud //Woolridge Test

quietly {
reg UEmean regpos_lire jahn1 fed deficit_t1 unemp_t1 openc ud //Pooled OLS
predict res, res //Vorhersage der Residuen
gen L1res = L1.res //1Jahreslag etc.
gen L2res = L2.res
gen L3res = L3.res
gen L4res = L4.res

xtreg res L1res, fe //es folgen die FE-Regressionen
est sto lag1 //speichern der Schtzergebnisse
xtreg res L2res, fe
est sto lag2
xtreg res L3res, fe
est sto lag3
xtreg res L4res, fe
est sto lag4
drop res L*
}
est tab lag*
drop _est*

*Schtzungen mit zeitlicher Dynamik*

*Pooled OLS mit ADL
gen ldv = l.UEmean // Generierung zeitverzgerter AV und UVs
gen lregpos = l.regpos
gen ljahn1 = l.jahn1
gen lfed = l.fed
gen ldef = l.deficit
gen lunem = l.unemp
gen lopenc = l.openc
gen lud = l.ud

quietly: reg UEmean ldv regpos_lire lregpos jahn1 ljahn fed lfed deficit_t1 ldef unemp_t1 lunem openc lopenc ud lud //Volles ADL-Modell
test lud //Test der Hypothese, ob einzelne Koeffizienten =0 sind (etc.)
test lopenc
test lunem
test ldef
test lfed
test ljahn1
test lregpos
test ldv

reg UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud // reduziertes ADL-Modell
rvfplot, mlabel(countryshort)
predict res, res //Residuen, um auf serielle Korrel zu testen
gen lagres = l.res
xtreg res lagres, fe
drop res lagres

*Pooled OLS mit LDV
reg UEmean ldv regpos_lire jahn1 fed deficit_t1 unemp_t1 openc ud //LDV-Modell

*Pooled OLS mit AR(1)-Korrektur (Prais Winsten)
xtpcse UEmean regpos_lire jahn1 fed deficit_t1 unemp_t1 openc ud, corr(ar1) independent //ar1-Korrektur ber Prais-Winsten

*First Differences
gen difUEmean = d.UEmean //neue abhngige Variable als Vernderungswerte
reg difUEmean regpos_lire jahn1 fed deficit_t1 unemp_t1 openc ud
predict res, res
gen lagres = l.res
xtreg res lagres, fe // verbleibende Autokorrelation
drop res lagres

*Tabelle zum Vergleich der verschiedenen dynamischen Spezifikationen

reg UEmean regpos_lire jahn1 fed deficit_t1 unemp_t1 openc ud //Pooled OLS
est sto mod1
reg UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud // reduziertes ADL-Modell
est sto mod2
reg UEmean ldv regpos_lire jahn1 fed deficit_t1 unemp_t1 openc ud //LDV-Modell
est sto mod3
xtpcse UEmean regpos_lire jahn1 fed deficit_t1 unemp_t1 openc ud, corr(ar1) independent //ar1-Korrektur ber Prais-Winsten
est sto mod4
reg difUEmean regpos_lire jahn1 fed deficit_t1 unemp_t1 openc ud
est sto mod5
esttab mod1 mod2 mod3 mod4 mod5 using tab.rtf, b star (* .1 ** .05 *** .01) t r2 noobs 


**3.3 HETEROGENITT**
*Dummies generieren
tab ccode, gen(dum)

*Vergleich pooled OLS und LSDV
reg UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud
est sto mod1
reg UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud dum*
est sto mod2
esttab mod1 mod2 using tab.rtf, b star (* .1 ** .05 *** .01) t r2 noobs 
drop _est*

*F-Test auf Fixed Effects
xtreg UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud, fe

*Reduktion von Heterogenitt durch Aufnahme weiterer inhaltlich begrndeter unabhngiger Variablen: Deindustrialisierung
xtreg UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud, fe
xtreg UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud deindus, fe //FE mit weiterer Variable

reg UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud //RVFPlot
rvfplot, mlabel(countrysh)

xtreg UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud deindus if ccode != 11, fe //FE-Regression ohne Italien
reg UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud deindus if ccode != 11 //RVFPlot ohne Italien
rvfplot, mlabel(countrysh)

*Finale Modelle
reg UEmean ldv regpos_lire jahn1 ljahn1 fed deficit_t1 unemp_t1 openc ud lud deindus //ADL ohne FE
xtpcse UEmean regpos_lire jahn1 fed deficit_t1 unemp_t1 openc ud deindus dum*, corr(ar1) independen //LSDV mit AR1



**3.4 HETEROSKEDASTIZITT**
*Test
reg UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud deindus if ccode != 11 
rvfplot //RVFPlot ohne Italien

quietly: reg UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud deindus if ccode != 11
hettest //Brsuch-Pagan-Cook-Weisberg Test

quietly: xtgls UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud deindus if ccode != 11
xttest3 //modifzierter Wald-Test

xtpcse UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud deindus if ccode != 11, hetonly //nur Het-Kontrolle
xtpcse UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud deindus if ccode != 11 //zum Vergleich ohne Het-Kontrolle

**3.5 RUMLICHE ABHNGIGKEIT**
*Test auf contemporaneous correl
xtpcse UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud if ccode != 11, hetonly //Ausgangsgleichung /ADL mit PCSE)
predict yhat, xb //Schtzwerte berechnen
gen res = UEmean - yhat //Residuen generieren (tatschliche Werte von Y - Schtzung)
xtcd res, resid //Pesaran-Test

xtpcse UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud if ccode != 11, hetonly //Ausgangsgleichung /ADL mit hetonly PCSE)
xtpcse UEmean ldv regpos_lire jahn1 ljahn fed deficit_t1 unemp_t1 openc ud lud if ccode != 11 //Zum Vergleich: ADL mit vollen PCSE



xtcsd, pesaran
