	********************************************************************************************************
	  ****************************************************************************************************
	  **																								**
	  **									Kapitel 7: Survival-Analysen								**
	  **																								**
	  **	Bitte zitieren Sie bei Verwendung dieses Do-Files											**
	  **	Wenzelburger, Georg/Jckle, Sebastian/Knig, Pascal: Weiterfhrende statistische Methoden 	**
	  **	fr Politikwissenschaftler. Eine anwendungsbezogene Einfhrung mit Stata, Oldenbourg 2014	**
	  **																								**
	  ** 	Verwendeter Datensatz: "Survival-Analysen.dta" 												**
	  **				   Quelle: eigene Erhebung (Jckle, Sebastian (2013) Ministerial turnover 		**
	  **						   in the German Lnder (19912010), in: Zeitschrift fr Vergleichende 	**
	  **						   Politikwissenschaft 7 (1): 2748.)									**
	  ****************************************************************************************************
	********************************************************************************************************


*****************
** Sterbetafel ** 
*****************

	* output 7.1 * 
ltable amtsdauer endereignis , survival by(ostdeu) intervals(30) 	/*Sterbetafel mit berlebensrate gruppiert nach Ost- und Westdeutschland, Intervalllnge 30 Tage*/

ltable amtsdauer endereignis , hazard by(ostdeu) intervals(30)		/*Sterbetafel mit Hazard-Rate gruppiert nach Ost- und Westdeutschland, Intervalllnge 30 Tage*/
ltable amtsdauer endereignis , failure by(ostdeu) intervals(30)		/*Sterbetafel mit kumulierter Wahrscheinlichkeitsdichte gruppiert nach Ost- und Westdeutschland, Intervalllnge 30 Tage*/

	* Abbildung 7.3 * 
ltable amtsdauer endereignis , graph notable survival ci by(ostdeu) over intervals(30) 		/*empirische berlebensfunktion aus Sterbetafel*/
ltable amtsdauer endereignis , graph notable failure ci by(ostdeu) over intervals(30) 		/*empirische kumulierte Wahrscheinlichkeitsdichtefunktion aus Sterbetafel*/
ltable amtsdauer endereignis , graph notable survival ci by(ostdeu) over intervals(365) 	/*zum Vergleich mit Einjahresintervallen --> glatterer Verlauf der Kurve*/
ltable amtsdauer endereignis , graph notable failure ci by(ostdeu) over intervals(365) 		/*zum Vergleich mit Einjahresintervallen --> glatterer Verlauf der Kurve*/

***********
** stset **
***********

	* output 7.3 *
stset amtsdauer, failure(endereignis==1) scale(365) 	/* Zunchst Daten als Survival-Daten kennzeichnen */ 
														/* Output auf Ungereimtheiten berprfen */
sort amtsdauer											/* fehlerhafte Observation --> Lschen */
drop if amtsdauer <0
					
stdescribe												/* gibt zusammenfassende Statistiken zu den Survival-Variablen; weitere Option zum Auffinden potentieller Fehler */

***************************
** Kaplan Meier Schtzer **
***************************

	* output 7.2 *
sts list, by(ostdeu) 													/* Kaplan Meier Produkt-Limit-Schtzer gruppiert nach West- und Ostdeutschland berechnen */

	* Abbildung 7.5 *
sts graph, by(ostdeu) level(90) ci censored(numbered)					/* Kaplan-Meier-berlebensfunktion */
sts graph, failure by(ostdeu) level(99) ci censored(numbered) 			/* Kaplan-Meier-Wahrscheinlichkeitsdichtefunktion */

sts graph, by(partei_num) level(90) ci censored(numbered)				/* Kaplan-Meier-berlebensfunktion getrennt nach Parteien --> unbersichtlich, da zu viele Subgruppen;
																		und v.a. bei den kleinen Parteien (Linke, Grne) sehr ungenaues Bild: groe Treppenstufen und extrem groe Konfidenzintervalle  */

	* Output 7.4 *
sts test ostdeu, logrank		/* Logrank-Test; default-Einstellung; sensitiver bei krzeren berlebenszeiten */ 
sts test ostdeu, cox			/* Cox-Test; */
sts test ostdeu, wilcoxon		/* Wilcoxon-Breslow-Gehan-Test; sensitiver bei lngeren berlebenszeiten */
sts test ostdeu, tware			/* Tarone-Ware-Test; */
sts test ostdeu, peto			/* Peto-Peto-Test; */
sts test ostdeu, fh (0 2)		/* Fleming-Harrington-Test; Wenn das erste Argument in der Klammer grer als das zweite ist, dann ist der Test bei kurzen berlebensdauern sensitiver;
								wenn das zweite - wie hier - grer ist, dann ist er bei langen berlebenszeiten sensitiver */	

***************************
** parametrische Modelle **
***************************

	* Output 7.5 *
streg, distribution(exponential) nohr   						/* rein exponentielles Modell, ohne Kovariate */
display exp(_b[_cons]) 											/* durchschnittliche Hazard-Rate */	

	* Abbildung 7.6 *
sts gen empsurvf = s											/* Speichern der Kaplan-Meier-Schtzer = empirische berlebensfunktion */
predict surv, surv												/* Speichern der auf basis des negativ exponentiellen Modells vorhergesagten berlebensraten */
twoway (scatter surv amtsdauer) (scatter empsurvf amtsdauer)	/* Plotten der empirischen Kaplan-Meier vs. der ber das exponentielle Model geschtzten berlebensfunktionen */
drop empsurvf surv

	* Output 7.6 *
streg ostdeu regional_verwurzelt, dist(exponential) 			/* exponentielles Modell mit Kovariaten */				
display 2*(e(ll)-e(ll_0))										/* "hndische" Berechnung der Likelihood-Ratio-Chi-Quadrat-Teststatistik */

streg, distribution(exponential)							
estimates store ll_0											/* Speichern der Log-Likelihood-Werte des rein exponentiellen Modells ohne Kovariate */
streg ostdeu regional_verwurzelt, distribution(exponential)
lrtest ll_0														/* Likelihood-Ratio-Chi-Quadrat-Test */

streg ostdeu regional_verwurzelt, distribution(weibull)			/* Weibull Modell als PH-Modell*/
streg ostdeu regional_verwurzelt, distribution(weibull)	time	/* Weibull Modell als AFT-Modell*/


	* Test der Proportionalittsannahme fr das Weibull-Modell*
gen mediandauerdummy = 1										
sum amtsdauer, detail											/* Sum mit Option detail, speichert den Median unter r(p50) */
replace mediandauerdummy = 0 if amtsdauer < r(p50)				/* Dummy fr die beiden Grruppen generieren */

streg ostdeu regional_verwurzelt if mediandauerdummy == 0, distribution(weibull)			/* Weibull Modell fr Observationen unter Mediandauer */
streg ostdeu regional_verwurzelt if mediandauerdummy == 1, distribution(weibull)			/* Weibull Modell fr Observationen ber Mediandauer */
		
	/*  --> die Log-Likelihood-Werte der beiden Modelle addieren,
		--> von dem Log-Likelihood-Wert des Gesamtmodells abziehen
		--> mit -2 multiplizieren = Teststatistik
		--> Vergleich mit theoretischem Chi-Quadrat-Wert (df = g-1) 
		
	hier: */
		display -2*(-679.30486-(-261.79622-224.44583))
	/*  = 386.12562 --> signifikanter Unterschied vorhanden (kritischer Chi-Quadrat-Wert bei g = 2 und 95%-Signifikanzniveau = 3,85) 
		--> Nullhypothese, dass die Effekte der Kovariaten auf die Hazard-Rate konstant ber die zeit sind, muss abgelehnt werden 
		--> Proportionalittsannahme falsch */ 

drop mediandauerdummy
		
	* Abbildung 7.8 * 		
	* Vergleich von stufenweise exponentiellen und Weibull-Hazard (zum Test ob Weibull-Funktion passt) *
stset amtsdauer, failure(endereignis==1) scale(365) id(id_1)									/* stset mit id --> gibt an, welche Zeilen einen gemeinsamen Fall, d.h. eine zu kumulierende berlebensdauer haben. Hier jede Zeile ein Fall */																
sum _t																							/* berlebensdauer auflisten um minima und Maxima zu sehen */
stsplit splitted_t, at(0(1)max)																	/* stsplit unterteilt alle berlebensdauern in krzere Perioden. Fr jede dieser Perioden wird eine Zeile angelegt. 
																								Hier: beginnend bei t=0 in 1-Jahresschritten. Die Zeilen einer Observation (gleiche id) unterscheiden sich ausschlielich 
																								in der neu angelegten Variable splitted_t, die die einzelnen Subperioden einer Observation kumuliert */ 
																								
sum splitted_t, detail																			/* zeigt die Verteilung dieser neuen Variable (um die einzelnen Stufen der exponentielle Funktionen mit etwa gleichvielen Observationen zu bestcken --> z.B. Quartile verwenden */
gen split_t1 = 0 <= splitted_t & splitted_t < 1													/* Dummies fr die Quartile generieren */
gen split_t2 = 1 <= splitted_t & splitted_t < 3
gen split_t3 = 3 <= splitted_t & splitted_t < 5
gen split_t4 = 5 <= splitted_t 
streg ostdeu regional_verwurzelt split_t2 split_t3 split_t4, distribution(exponential)			/* Exponentielles Modell rechnen mit den Dummy-Variablen */
gen step_hazard =exp(_b[_cons] + _b[split_t2] * split_t2 + _b[split_t3] * split_t3 + ///		/* hndisches Vorhersagen der Hazard-Werte entsprechend der exponentiellen Stufenfunktion */
_b[split_t4] * split_t4)
line step_hazard splitted_t, c(J) sort l1title("Step Function Baseline Hazard")					/* Plotten der exponentiellen Stufenfunktion --> So nur schwer zu erkennen, ob Weibull passen wrde, deshalb Weibull mit reinlegen */
streg ostdeu regional_verwurzelt, distribution(weibull)											/* Weibull-Modell rechnen */
gen platzh_ostdeu = ostdeu																		/* Platzhaltervariable generieren, damit man fr Baseline-Modell die Variablen alle auf Null setzen kann und danach wieder zurcktauschen */
gen platzh_regional_verwurzelt = regional_verwurzelt
replace ostdeu = 0													
replace regional_verwurzelt = 0
predict hazard_weibull, hazard																	/* Weibull-Hazard vorhersagen */
replace ostdeu = platzh_ostdeu																	/* ursprngliche Variablenwerte wiederherstellen */
replace regional_verwurzelt = platzh_regional_verwurzelt
line step_hazard hazard_weibull _t, c(l l) sort l1title("Step Function Baseline Hazard")		/* Plotten der stufenweise exponentiellen und der Weibull Funktion */

keep if endereignis ==1 | endereignis ==0														/* ursprnglichen Datensatz wiederherstellen */
drop  splitted_t split_* platzh* step_hazard hazard_weibull
								
streg ostdeu regional_verwurzelt, distribution(gompertz)										/* Gompertz-Modell */
streg ostdeu regional_verwurzelt, distribution(loglogistic)										/* log-logistisches Modell */

***************************
** 		Cox Modell		 **
***************************

	* Output 7.7 *
stset amtsdauer, failure(endereignis==1) scale(365) id(id_1)
stcox ostdeu regional_verwurzelt, nohr exactm						/* Ausgabe in Form von Partial-Likelihood-Koeffizienten */

	* Output 7.8 *
stcox ostdeu regional_verwurzelt, exactm							/* Ausgabe in Form von hazard-Ratios: Approximation der PL bei Ties ber exact-marginal-likelihood = averaged likelihood*/

stcox ostdeu regional_verwurzelt, breslow							/* Ausgabe in Form von hazard-Ratios: Approximation der PL bei Ties ber Breslow-Methode*/
stcox ostdeu regional_verwurzelt, efron								/* Ausgabe in Form von hazard-Ratios: Approximation der PL bei Ties ber Efron-Methode*/
stcox ostdeu regional_verwurzelt, exactp							/* Ausgabe in Form von hazard-Ratios: Approximation der PL bei Ties ber exact-partial-likelihood-Methode*/

** Stratifizierte Modelle **
	* Tabelle 7.2 *
stcox regional_verwurzelt, exactm
stcox regional_verwurzelt ostdeu, exactm
stcox regional_verwurzelt if ostdeu, exactm
stcox regional_verwurzelt if !ostdeu, exactm
stcox regional_verwurzelt, strata(ostdeu) exactm

	* Abbildung 7.9 Log-Log-Plots fr Test der PH-Annahme *
stset amtsdauer, failure(endereignis==1) scale(365) id(id_1)
stphplot, by(ostdeu)
stphplot, by(regional_verwurzelt)

	* Abbildung 7.10 Kaplan-Meier und Cox-Plots *
stcoxkm, by(ostdeu) sep
stcoxkm, by(regional_verwurzelt) sep

	* Abbildung 7.11 Schoenfeld-Residuen Plot + LOWESS
stcox ostdeu regional_verwurzelt, scaledsch(sca*) schoenfeld(sch*) efron
estat phtest, plot(ostdeu)
estat phtest, plot(regional_verwurzelt)

estat phtest, plot(ostdeu) bwidth(0.5)
estat phtest, plot(regional_verwurzelt) bwidth(0.5)

estat phtest, plot(ostdeu) bwidth(1)
estat phtest, plot(regional_verwurzelt) bwidth(1)

estat phtest, log plot(ostdeu)
estat phtest, log plot(regional_verwurzelt)

	* Output 7.9 *
estat phtest, detail
estat phtest, log detail
estat phtest, km detail
estat phtest, rank detail

** Competing Risks Modelle
	* Output 7.10 *
stset amtsdauer, failure(freiwillig==1) scale(365) id(id_1) 						/* stset der Daten fr die freiwilligen Rcktritte, alle anderen werden zensiert */
stcox ostdeu regional_verwurzelt, exactm											/* am eigentlichen Cox-Modell ndert der Competing-Risks-Ansatz nichts */

stset amtsdauer, failure(erzwungen==1) scale(365) id(id_1) 							/* stset der Daten fr die erzwungenen Rcktritte, alle anderen werden zensiert */
stcox ostdeu regional_verwurzelt, exactm 

stset amtsdauer, failure(kollektiv==1) scale(365) id(id_1) 							/* stset der Daten fr die kollektiven Rcktritte, alle anderen werden zensiert */
stcox ostdeu regional_verwurzelt, exactm

** Baseline-Hazard-Rate
	* Abbildung 7.12 *
stset amtsdauer, failure(endereignis==1) scale(365) id(id_1) 
stcox ostdeu regional_verwurzelt, exactm basesurv(ueberleben) basec(kumulativ)
line ueberleben _t, sort c(J) /*baseline survival function*/
line kumulativ _t, sort c(J) /*cumulative baseline hazard*/

line ueberleben _t , sort c(J)|| histogram _t /*baseline survival function mit Histogramm der Amtsdauern*/
line kumulativ _t, sort c(J) || histogram _t /*cumulative baseline hazard mit */

	* Abbildung 7.13 *
stcurve, surv at(ostdeu = 0 regional_verwurzelt = 0) 
stcurve, cumh at(ostdeu = 0 regional_verwurzelt = 0)
stcurve, hazard at(ostdeu = 0 regional_verwurzelt = 0)kernel(epanechnikov)
stcurve, hazard at(ostdeu = 0 regional_verwurzelt = 0)kernel(epan2)
stcurve, hazard at(ostdeu = 0 regional_verwurzelt = 0)kernel(biweight)
stcurve, hazard at(ostdeu = 0 regional_verwurzelt = 0)kernel(cosine)
stcurve, hazard at(ostdeu = 0 regional_verwurzelt = 0)kernel(gaussian) 
stcurve, hazard at(ostdeu = 0 regional_verwurzelt = 0)kernel(parzen)
stcurve, hazard at(ostdeu = 0 regional_verwurzelt = 0)kernel(rectangle)
stcurve, hazard at(ostdeu = 0 regional_verwurzelt = 0)kernel(triangle)

stcurve, surv at1(ostdeu = 0 regional_verwurzelt = 0) at2(ostdeu = 1 regional_verwurzelt = 0)
stcurve, hazard at1(ostdeu = 0 regional_verwurzelt = 0) ///
				at2(ostdeu = 1 regional_verwurzelt = 0) ///
				at3(ostdeu = 0 regional_verwurzelt = 1) ///
				at4(ostdeu = 1 regional_verwurzelt = 1)

** Gtemae und Residuendiagnostik
stset amtsdauer, failure(endereignis==1) scale(365) id(id_1) 
stcox ostdeu regional_verwurzelt, exactm 
	* Output 7.11 *
estat concordance										/* Harrell's C */

	* Abbilung 7.14a *
stcox ostdeu regional_verwurzelt, exactm      			
predict double cs, csnell								/*Cox-Snell-Residuen vorhersagen*/
stset cs, failure(endereignis==1)						/*stset mit Cox-Snell-Residuals als neue failure time data*/
sts generate km = s										/*Kaplan-Meier-Schtzer generieren*/
gen double H = -ln(km)									/*kumulierten hazard generieren*/
line H cs cs, sort legend(nodraw)						/*Plot des kumulierten hazards gegen die Cox-Snell-Residuen*/

	* Abbildung 7.14b *
stcox ostdeu regional_verwurzelt, exactm mgale(mg) 		/*speichern der Martingalen Residuen*/
lowess mg ostdeu, mean noweight title("") m(o)
lowess mg regional_verwurzelt, mean noweight title("") m(o)

	* Abbildung 7.15a und 7.15b
predict dev, deviance									/*Deviance-Residuen vorhersagen*/
scatter dev id_1,  mlabel(Nachname)						/*Plot der Deviance-Residuen gegen die Observationsnummer*/
scatter dev id_1, 
gen dev_abs = abs(dev)
sort dev_abs
list dev_abs Nachname in -10/L
lowess dev amtsdauer 									/* Plot der Deviance-Residuen gegen die Amtsdauer */

	* Abbildung 7.16							
stcox ostdeu regional_verwurzelt, exactm esr(esr*)   	/*Score-Residuen vorhersagen*/
set matsize 1000										/*Matsize erhhen, da die Berechnung der Matrix sonst nicht funktioniert*/
mkmat esr1 esr2 , matrix(esr)							/*Berechnung der Score-Residuen-Matrix*/
mat V = e(V)											/*Berechnung der Varianz-Kovarianz-Matrix*/
mat Influence = esr*V									/*Berechnung der Einflusswerte (dfbetas) durch Multiplizierung der beiden Matrizen*/
svmat Influence, names(s)								/*Speichern der dfbetas*/
label var s1 "ostdeu"									/*Labeln der dfbetas*/
label var s2 "regional_verwurzelt"
graph box s1 s2, marker(1,mlab(Nachname)) marker(2,mlab(Nachname))

scatter s1 id_1,  ytitle("influence ostdeu")			/*Scatterplot dfbetas vs. Observationsnummer, optional Identifizierung der Observationen mittels mlabel*/
scatter s2 id_1,  ytitle("influence regional_verwurzelt")

scatter s1 amtsdauer, mlabel(id_1) ytitle("influence caretaker") /*scatterplot dfbetas vs. government duration*/
scatter s2 amtsdauer, mlabel(id_1) ytitle("influence dauer_end_legp_month")

** time-varying covariates **
clear all					/* Gre des internen Speichers muss erhht werden. Das geht aber nur ohne dass ein Datensatz geladen ist. */
set memory 700m

* Datensatz neu laden

expand amtsdauer           														/* fr jeden Tag amtsdauer eine extra observation (Zeile) */
sort id_1 
quietly by id: gen amtsdauer_tv = _n 											/* Neue amtsdauer-Variable, die Werte von 1, 2, 3 usw. annimmt innerhalb jeder id */  
gen endereignis_tv = 0															/* neue Endereignis-Variable, die ausschlielich in der letzten Zeile einer Observation den vorherigen Endereignis-Wert annimmt, ansonsten immer Null */
quietly by id_1: replace endereignis_tv = endereignis if _n ==_N 
gen parteimitgliedschaft_tv = (parteimitgliedschaft_anfang + amtsdauer_tv)/365 /* Parteimitgliedschaft time-varying generieren, 
	
	* Output 7.12 *																			standardisiert auf Jahre um grere und damit besser interpretierbare Koeffizienten zu erhalten */
stset amtsdauer_tv, failure(endereignis_tv==1) scale(365) id(id_1)
stcox ostdeu regional_verwurzelt, exactm										/* Test: muss dasselbe Ergebnis liefern, wie ursprngliches Cox-Modell */
stcox ostdeu regional_verwurzelt parteimitgliedschaft_tv, exactm

 
